@@ -8,7 +8,7 @@
  * This program is open source, licensed under the PostgreSQL license.
  * For license terms, see the LICENSE file.
  *
- * Copyright (C) 2015-2023: Julien Rouhaud
+ * Copyright (C) 2015-2024: Julien Rouhaud
  *
  *-------------------------------------------------------------------------
  */
@@ -1289,9 +1289,6 @@ hypopg(PG_FUNCTION_ARGS)
 		tuplestore_putvalues(tupstore, tupdesc, values, nulls);
 	}
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	return (Datum) 0;
 }
 
@@ -1371,9 +1368,6 @@ hypopg_create_index(PG_FUNCTION_ARGS)
 		i++;
 	}
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	return (Datum) 0;
 }
 
@@ -1473,13 +1467,13 @@ hypopg_get_indexdef(PG_FUNCTION_ARGS)
 		if (entry->indexkeys[keyno] != 0)
 		{
 			int32		keycoltypmod;
+			char *attname;
 #if PG_VERSION_NUM >= 110000
-			appendStringInfo(&buf, "%s", get_attname(entry->relid,
-													 entry->indexkeys[keyno], false));
+			attname = get_attname(entry->relid, entry->indexkeys[keyno], false);
 #else
-			appendStringInfo(&buf, "%s", get_attname(entry->relid,
-													 entry->indexkeys[keyno]));
+			attname = get_attname(entry->relid, entry->indexkeys[keyno]);
 #endif
+			appendStringInfo(&buf, "%s", quote_identifier(attname));
 
 			get_atttypetypmodcoll(entry->relid, entry->indexkeys[keyno],
 								  &keycoltype, &keycoltypmod,
@@ -1547,11 +1541,13 @@ hypopg_get_indexdef(PG_FUNCTION_ARGS)
 		appendStringInfo(&buf, " INCLUDE (");
 		for (keyno = entry->nkeycolumns; keyno < entry->ncolumns; keyno++)
 		{
+			char *attname;
+
 			if (keyno != entry->nkeycolumns)
 				appendStringInfo(&buf, ", ");
 
-			appendStringInfo(&buf, "%s", get_attname(entry->relid,
-													 entry->indexkeys[keyno], false));
+			attname = get_attname(entry->relid, entry->indexkeys[keyno], false);
+			appendStringInfo(&buf, "%s", quote_identifier(attname));
 		}
 		appendStringInfo(&buf, ")");
 	}
@@ -1719,9 +1715,6 @@ hypopg_hidden_indexes(PG_FUNCTION_ARGS)
 		tuplestore_putvalues(tupstore, tupdesc, values, nulls);
 	}
 
-	/* clean up and return the tuplestore */
-	tuplestore_donestoring(tupstore);
-
 	return (Datum) 0;
 }
 
@@ -1738,8 +1731,8 @@ hypo_index_unhide(Oid indexid)
 }
 
 /*
- * Check rel and delete the same oid index as hypoHiddenIndexes
- * in rel->indexlist.
+ * Remove any existing index in the given relation list of indexes if they
+ * match an index that has been hidden.
  */
 void
 hypo_hideIndexes(RelOptInfo *rel)
@@ -1789,8 +1782,10 @@ hypo_hideIndexes(RelOptInfo *rel)
 static void
 hypo_set_indexname(hypoIndex * entry, char *indexname)
 {
-	char		oid[12];		/* store <oid>, oid shouldn't be more than
-								 * 9999999999 */
+	char		oid[13];		/* store <oid>, oid is an unsigned int32, so it
+								 * shouldn't be more than 4B, so 10 digits.
+								 * We add 2 chars for the < and > separators
+								 * and an extra null char.*/
 	int			totalsize;
 
 	snprintf(oid, sizeof(oid), "<%d>", entry->oid);
